@@ -82,12 +82,7 @@ fn merge_configs(input: Vec<(PathBuf, Value)>) -> Result<Value> {
     Ok(Value::Array(merged))
 }
 
-pub fn parse(path: impl AsRef<Path>, glob_files: bool) -> Result<Config> {
-    let files = if glob_files {
-        glob_config_files(path)
-    } else {
-        vec![path.as_ref().into()]
-    };
+fn parse_files(files: Vec<PathBuf>) -> Result<Config> {
     let parsed_files = files
         .into_iter()
         .map(|path| {
@@ -118,6 +113,14 @@ pub fn parse(path: impl AsRef<Path>, glob_files: bool) -> Result<Config> {
     })
 }
 
+pub fn parse(path: impl AsRef<Path>) -> Result<Config> {
+    parse_files(glob_config_files(path))
+}
+
+pub fn parse_glob(path: impl AsRef<Path>) -> Result<Config> {
+    parse_files(glob_config_files(path))
+}
+
 fn parse_db_options(parsed: &Value) -> Result<Database> {
     match parsed["dbtype"].as_str() {
         Some("mysql") => {
@@ -346,7 +349,7 @@ use std::fmt::Debug;
 
 #[cfg(test)]
 fn config_from_file(path: &str) -> Config {
-    parse(path, false).unwrap()
+    parse(path).unwrap()
 }
 
 #[test]
@@ -550,7 +553,7 @@ fn test_parse_redis_cluster() {
 
 #[test]
 fn test_parse_config_multiple() {
-    let config = parse("tests/configs/multiple/config.php", true).unwrap();
+    let config = parse_glob("tests/configs/multiple/config.php").unwrap();
     assert_eq!("https://cloud.example.com", config.nextcloud_url);
     assert_eq!("oc_", config.database_prefix);
     assert_debug_equal(
